@@ -4,7 +4,10 @@ use serde::Serialize;
 use std::collections::{HashMap, HashSet};
 use urls::{SET, SIGNER};
 
-use crate::{Atom, Resource, Storelike, Value, datatype::DataType, errors::AtomicResult, resources::PropVals, urls};
+use crate::{
+    datatype::DataType, errors::AtomicResult, resources::PropVals, urls, Atom, Resource, Storelike,
+    Value,
+};
 
 /// A Commit is a set of changes to a Resource.
 /// Use CommitBuilder if you're programmatically constructing a Delta.
@@ -107,7 +110,7 @@ impl Commit {
             Err(_) => {
                 is_new = true;
                 Resource::new(self.subject.clone())
-            },
+            }
         };
         // We apply the Commit, but don't save the resource just yet.
         // This _must_ be a clone, because otherwise we could have malicious agents granting themselves rights
@@ -145,6 +148,7 @@ impl Commit {
         // TODO: Should we remove the existing commits too? Probably.
         if let Some(destroy) = self.destroy {
             if destroy {
+                // Note: the value index is updated before this action, in resource.apply_changes()
                 store.remove_resource(&self.subject)?;
                 return Ok(commit_resource);
             }
@@ -155,9 +159,14 @@ impl Commit {
         Ok(commit_resource)
     }
 
-    /// Updates the values in the Resource according to the `set` and `remove` attributes in the Commit.
+    /// Updates the values in the Resource according to the `set`, `remove` and `destroy` attributes in the Commit.
     /// Optionally also updates the index in the Store.
-    pub fn apply_changes(&self, mut resource: Resource, store: &impl Storelike, update_index: bool) -> AtomicResult<Resource> {
+    pub fn apply_changes(
+        &self,
+        mut resource: Resource,
+        store: &impl Storelike,
+        update_index: bool,
+    ) -> AtomicResult<Resource> {
         if let Some(set) = self.set.clone() {
             for (prop, val) in set.iter() {
                 if update_index {
@@ -180,6 +189,13 @@ impl Commit {
                 resource.remove_propval(&prop);
             }
         }
+        if let Some(destroy) = self.destroy {
+            if destroy {
+                for atom in resource.to_atoms()?.iter() {
+                    store.remove_atom_from_index(&atom)?;
+                }
+            }
+        }
         Ok(resource)
     }
 
@@ -284,7 +300,7 @@ impl Commit {
     }
 
     /// Generates a deterministic serialized JSON-AD representation of the Commit.
-    /// Does not contain the signature, since this function is used to check if the signature is correct.
+    /// Removes the signature from the object before serializing, since this function is used to check if the signature is correct.
     pub fn serialize_deterministically_json_ad(
         &self,
         store: &impl Storelike,
@@ -293,7 +309,7 @@ impl Commit {
         // A deterministic serialization should not contain the hash (signature), since that would influence the hash.
         commit_resource.remove_propval(urls::SIGNATURE);
         let json_obj =
-            crate::serialize::propvals_to_json_map(commit_resource.get_propvals(), None)?;
+            crate::serialize::propvals_to_json_ad_map(commit_resource.get_propvals(), None)?;
         serde_json::to_string(&json_obj).map_err(|_| "Could not serialize to JSON-AD".into())
     }
 }
@@ -378,12 +394,7 @@ fn sign_at(
         .serialize_deterministically_json_ad(store)
         .map_err(|e| format!("Failed serializing commit: {}", e))?;
     let private_key = agent.private_key.clone().ok_or("No private key in agent")?;
-    let signature = sign_message(
-        &stringified,
-        &private_key,
-        &agent.public_key,
-    )
-    .map_err(|e| {
+    let signature = sign_message(&stringified, &private_key, &agent.public_key).map_err(|e| {
         format!(
             "Failed to sign message for resource {} with agent {}: {}",
             commit.subject, agent.subject, e
