@@ -1,12 +1,12 @@
 //! A resource is a set of Atoms that share a URL
 
+use crate::values::Value;
 use crate::{commit::CommitBuilder, errors::AtomicResult};
 use crate::{
     mapping::is_url,
     schema::{Class, Property},
     Atom, Storelike,
 };
-use crate::{values::Value};
 use std::collections::HashMap;
 
 /// A Resource is a set of Atoms that shares a single Subject.
@@ -30,10 +30,10 @@ impl Resource {
         let classvec = self.get_classes(store)?;
         for class in classvec.iter() {
             for required_prop in class.requires.clone() {
-                self.get(&required_prop).map_err(|e| {
+                self.get(&required_prop).map_err(|_e| {
                     format!(
-                        "Property {} missing in class {}. {} ",
-                        &required_prop, class.subject, e
+                        "Property {} missing. Is required in class {} ",
+                        &required_prop, class.subject
                     )
                 })?;
             }
@@ -297,8 +297,8 @@ impl Resource {
     }
 
     /// Changes the subject of the Resource.
-    /// TODO: Handle these changes in Commits
-    /// introduce 'move' command? https://github.com/joepio/atomic/issues/44
+    /// Does not 'move' the Resource
+    /// See https://github.com/joepio/atomic/issues/44
     pub fn set_subject(&mut self, url: String) {
         self.commit.set_subject(url.clone());
         self.subject = url;
@@ -306,7 +306,7 @@ impl Resource {
 
     /// Converts Resource to JSON-AD string.
     pub fn to_json_ad(&self) -> AtomicResult<String> {
-        let obj = crate::serialize::propvals_to_json_map(
+        let obj = crate::serialize::propvals_to_json_ad_map(
             self.get_propvals(),
             Some(self.get_subject().clone()),
         )?;
@@ -339,11 +339,7 @@ impl Resource {
     pub fn to_atoms(&self) -> AtomicResult<Vec<Atom>> {
         let mut atoms: Vec<Atom> = Vec::new();
         for (property, value) in self.propvals.iter() {
-            let atom = Atom::new(
-                self.subject.to_string(),
-                property.clone(),
-                value.clone(),
-            );
+            let atom = Atom::new(self.subject.to_string(), property.clone(), value.clone());
             atoms.push(atom);
         }
         Ok(atoms)
