@@ -1,10 +1,10 @@
 //! The Storelike Trait contains many useful methods for maniupulting / retrieving data.
 
-use crate::{errors::AtomicResult, parse::parse_json_ad_array};
 use crate::{
     agents::Agent,
     schema::{Class, Property},
 };
+use crate::{errors::AtomicResult, parse::parse_json_ad_array};
 use crate::{mapping::Mapping, values::Value, Atom, Resource};
 
 // A path can return one of many things
@@ -80,7 +80,7 @@ pub trait Storelike: Sized {
     /// An Agent is required for signing Commits.
     /// Returns a tuple of (subject, private_key).
     /// Make sure to store the private_key somewhere safe!
-    /// Does not create a Commit.
+    /// Does not create a Commit - the recommended way is to use `agent.to_resource().save_locally()`.
     fn create_agent(&self, name: Option<&str>) -> AtomicResult<crate::agents::Agent> {
         let agent = Agent::new(name, self)?;
         self.add_resource(&agent.to_resource(self)?)?;
@@ -153,7 +153,8 @@ pub trait Storelike: Sized {
 
     /// Imports a JSON-AD string, returns the amount of imported resources
     fn import(&self, string: &str) -> AtomicResult<usize> {
-        let vec = parse_json_ad_array(string, self).map_err(|e| format!("Unable to parse JSON-AD string: {}", e))?;
+        let vec = parse_json_ad_array(string, self)
+            .map_err(|e| format!("Unable to parse JSON-AD string: {}", e))?;
         let len = vec.len();
         for r in vec {
             self.add_resource(&r)?
@@ -182,7 +183,7 @@ pub trait Storelike: Sized {
     ///     Some("[\"https://atomicdata.dev/classes/Class\"]"),
     ///     true
     /// ).unwrap();
-    /// assert_eq!(atoms.len(), 11)
+    /// assert!(atoms.len() > 11)
     /// ```
     // Very costly, slow implementation.
     // Does not assume any indexing.
@@ -207,7 +208,7 @@ pub trait Storelike: Sized {
                     vec.push(Atom::new(
                         resource.get_subject().clone(),
                         property.clone(),
-                        value.clone()
+                        value.clone(),
                     ))
                 }
             }
